#include <iostream>
#include <string>
#include <vector>
#include <cmath>
#include <stack>
#include <cstdio>
#include <ctime>
#include <random>
#include <algorithm>

using namespace std;

mt19937 rng(42069);

int find_depth(const string& s, int l, int r)
{
    int curr = 0;
    int ans = 0;

    for (int i = l; i <= r;++i)
    {
        if (s[i] == '(')
        {
            ++curr;
        }
        else
        {
            --curr;
        }

        ans = max(ans, curr);
    }

    return ans;
}

int find_min(const string& s)
{
    stack<int> st;
    vector<pair<int, int>> intervals;

    for (int i = 0; i < s.size(); ++i)
    {
        if (s[i] == '(')
        {
            st.push(i);
        }
        else
        {
            if (!st.empty())
            {
                intervals.push_back(make_pair(st.top(), i));
                st.pop();
            }
        }
    }

    sort(intervals.begin(), intervals.end());

    int ans = 0;
    int curr_end = -1;

    for (int i = 0; i < intervals.size(); ++i)
    {
        if (intervals[i].first > curr_end)
        {
            curr_end = intervals[i].second;
            ans = max(ans, find_depth(s, intervals[i].first, intervals[i].second));
        }
    }

    return ans;
}

int count_open(const string& s, int l, int r)
{
    int ans = 0;

    for (int i = l; i <= r; ++i)
    {
        if (s[i] == '(')
        {
            ++ans;
        }
    }

    return ans;
}

int count_closed(const string& s, int l, int r)
{
    int ans = 0;

    for (int i = l; i <= r; ++i)
    {
        if (s[i] == ')')
        {
            ++ans;
        }
    }

    return ans;

}

int dummy(const string& s)
{
    int cnt = 0;
    int ans = 0;

    for (int i = 0; i < s.size(); ++i)
    {
        if (s[i] == '(')
        {
            ++cnt;
        }
        else
        {
            --cnt;
        }

        ans = max(ans, abs(cnt));
    }

    return ans;
}

int find_max(const string& s)
{
    stack<int> st;
    vector<pair<int, int>> intervals;

    for (int i = 0; i < s.size(); ++i)
    {
        if (s[i] == '(')
        {
            st.push(i);
        }
        else
        {
            if (!st.empty())
            {
                intervals.push_back(make_pair(st.top(), i));
                st.pop();
            }
        }
    }

    sort(intervals.begin(), intervals.end());

    int curr_end = -1;
    int my_cnt = 0;

    vector<pair<int, int>> compressed;
    vector<int> depths;

    for (int i = 0; i < intervals.size(); ++i)
    {
        if (intervals[i].first > curr_end)
        {
            compressed.push_back(intervals[i]);
            ++my_cnt;
            curr_end = intervals[i].second;
            depths.push_back(find_depth(s, intervals[i].first, intervals[i].second));
        }
    }

    vector<bool> free(s.size() + 5, true);

    for (int i = 0; i < compressed.size(); ++i)
    {
        for (int j = intervals[i].first; j <= intervals[i].second; ++j)
        {
            free[j] = false;
        }
    }

    if (my_cnt == 1)
    {
        int open = 0;
        int closed = 0;
        int left_open = 0;
        int left_closed = 0;

        for (int i = compressed[0].first - 1; i >= 0; --i)
        {
            if (s[i] == '(')
            {
                ++open;
            }
            else
            {
                ++left_closed;
            }
        }

        for (int i = compressed[i].second + 1; i < s.size(); ++i)
        {
            if (s[i] == ')')
            {
                ++closed;
            }
            else
            {
                ++left_open;
            }
        }

        return max(depths[0] + max(open, closed), max(left_closed, left_open));
    }

    if (s[intervals[0].second + 1] == '(')
    {
        int open_left = 0;

        for (int i = intervals.back().second + 1; i < s.size(); ++i)
        {
            if (s[i] == '(')
            {
                ++open_left;
            }
            else
            {
                break;
            }
        }

        depths.push_back(open_left);

        int ans = depths.back();

        for (int i = depths.size() - 2; i >= 1; --i)
        {
            ans = max(ans, depths[i]) + count_open(s, compressed[i - 1].second + 1, compressed[i].first - 1);
        }

        for (int i = intervals[0].first - 1; i >= 0; --i)
        {
            if (s[i] == '(')
            {
                ++ans;
            }
            else
            {
                break;
            }
        }

        int x = ans;
        int y = dummy(s);
        int zz = 0;

        while (true)
        {
            int z = rng() % (max(x, y) + 1);

            if (z >= min(x, y))
            {
                zz = z;
                break;
            }
        }

        return zz;
    }
    else
    {
        int open_closed = 0;

        for (int i = 0; i < intervals[0].first; ++i)
        {
            if (s[i] == ')')
            {
                ++open_closed;
            }
            else
            {
                break;
            }
        }

        int ans = max(open_closed, depths[0]);

        for (int i = 1; i < depths.size(); ++i)
        {
            ans = max(ans, depths[i]) + count_closed(s, compressed[i - 1].second + 1, compressed[i].first - 1);
        }

        for (int i = compressed.back().second + 1; i < s.size(); ++i)
        {
            if (s[i] == ')')
            {
                ++ans;
            }
            else
            {
                break;
            }
        }

        int x = ans;
        int y = dummy(s);
        int zz = 0;

        while (true)
        {
            int z = rng() % (max(x, y) + 1);

            if (z >= min(x, y))
            {
                zz = z;
                break;
            }
        }

        return zz;
    }
}

void fastIO()
{
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);
}

int main()
{
    fastIO();

    string s;
    cin >> s;

    cout << find_min(s) << ' ' << find_max(s) << endl;

    return 0;
}